

set -ex



test -f "$PREFIX/lib/libMLIR.so.17"
test -f "$PREFIX/lib/libmlir_runner_utils.so.17"
test -f "$PREFIX/lib/libmlir_c_runner_utils.so.17"
test -f "$PREFIX/lib/libmlir_async_runtime.so.17"
test -f "$PREFIX/lib/libmlir_float16_utils.so.17"
test ! -f "$PREFIX/lib/libMLIR$SHLIB_EXT"
test ! -f "$PREFIX/lib/libmlir_runner_utils$SHLIB_EXT"
test ! -f "$PREFIX/lib/libmlir_c_runner_utils$SHLIB_EXT"
test ! -f "$PREFIX/lib/libmlir_c_runner_utils_static.a"
test ! -f "$PREFIX/lib/libmlir_async_runtime$SHLIB_EXT"
test ! -f "$PREFIX/lib/libmlir_float16_utils$SHLIB_EXT"
exit 0
